@@ -28,7 +28,7 @@ from math import isnan
 from fluids.numerics import linspace, assert_close, derivative, assert_close1d
 from chemicals.vapor_pressure import *
 from thermo.vapor_pressure import *
-from thermo.vapor_pressure import SANJARI, EDALAT, AMBROSE_WALTON, LEE_KESLER_PSAT, BOILING_CRITICAL, COOLPROP, VDI_PPDS, VDI_TABULAR, WAGNER_MCGARRY, ANTOINE_EXTENDED_POLING, ANTOINE_POLING, WAGNER_POLING, DIPPR_PERRY_8E
+from thermo.vapor_pressure import SANJARI, EDALAT, AMBROSE_WALTON, LEE_KESLER_PSAT, BOILING_CRITICAL, COOLPROP, VDI_PPDS, VDI_TABULAR, WAGNER_MCGARRY, ANTOINE_EXTENDED_POLING, ANTOINE_POLING, WAGNER_POLING, DIPPR_PERRY_8E, ANTOINE_WEBBOOK
 from thermo.utils import TDependentProperty
 from chemicals.identifiers import check_CAS
 import chemicals
@@ -44,7 +44,7 @@ def test_VaporPressure_CoolProp():
     assert_close(EtOH.calculate(305.0, COOLPROP), 11592.205263402893, rtol=1e-7)
 
 @pytest.mark.meta_T_dept
-def test_VaporPressure():
+def test_VaporPressure_ethanol():
     # Ethanol, test as many methods asa possible at once
     EtOH = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')
     
@@ -57,7 +57,7 @@ def test_VaporPressure():
     # Check valid_methods call
     assert set(EtOH.valid_methods()) == EtOH.all_methods
     # For Ethanol, all methods are valid around 300 K
-    assert EtOH.valid_methods(300) == EtOH.valid_methods()
+    assert EtOH.valid_methods(365) == EtOH.valid_methods()
     
     # Check test_property_validity
     assert not EtOH.test_property_validity(1j)
@@ -70,6 +70,8 @@ def test_VaporPressure():
     methods.remove(VDI_TABULAR)
     if COOLPROP in methods:
         methods.remove(COOLPROP)
+        
+    EtOH.extrapolation = 'nolimit'
 
     Psats_expected = {WAGNER_MCGARRY: 11579.634014300127,
                      WAGNER_POLING: 11590.408779316374,
@@ -80,7 +82,9 @@ def test_VaporPressure():
                      LEE_KESLER_PSAT: 11350.156640503357,
                      AMBROSE_WALTON: 11612.378633936816,
                      SANJARI: 9210.262000640221,
-                     EDALAT: 12081.738947110121}
+                     EDALAT: 12081.738947110121,
+                     ANTOINE_WEBBOOK: 10827.523813517917,
+                     }
 
     T = 305.0
     Psat_calcs = {}
@@ -88,7 +92,8 @@ def test_VaporPressure():
         EtOH.method = i
         Psat_calcs[i] = EtOH.T_dependent_property(T)
         Tmin, Tmax = EtOH.T_limits[i]
-        assert Tmin < T < Tmax
+        if i not in (ANTOINE_WEBBOOK,):
+            assert Tmin < T < Tmax
 
     for k, v in Psats_expected.items():
         assert_close(v, Psat_calcs[k], rtol=1e-11)
@@ -101,8 +106,17 @@ def test_VaporPressure():
     obj2 = VaporPressure.from_json(s)
     assert EtOH == obj2
 
+    # Test that methods return None
+    EtOH = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')
+    EtOH.extrapolation = None
+    for i in list(EtOH.all_methods):
+        EtOH.method = i
+        assert EtOH.T_dependent_property(5000) is None
 
 
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_extended_poling():
     # Use another chemical to get in ANTOINE_EXTENDED_POLING
     a = VaporPressure(CASRN='589-81-1')
 
@@ -112,19 +126,15 @@ def test_VaporPressure():
         Psat_calcs.append(a.T_dependent_property(410))
 
 
-    Psat_exp = [162944.82134710113, 162870.44794192078, 162865.5380455795]
+    Psat_exp = [162944.82134710113, 162870.44794192078, 170508.47471278594, 162865.5380455795]
     assert_close1d(sorted(Psat_calcs), sorted(Psat_exp))
 
     s = a.as_json()
     obj2 = VaporPressure.from_json(s)
     assert a == obj2
 
-    # Test that methods return None
-    EtOH = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')
-    EtOH.extrapolation = None
-    for i in list(EtOH.all_methods):
-        EtOH.method = i
-        assert EtOH.T_dependent_property(5000) is None
+@pytest.mark.meta_T_dept
+def test_VaporPressure_water():
 
     # Test interpolation, extrapolation
     w = VaporPressure(Tb=373.124, Tc=647.14, Pc=22048320.0, omega=0.344, CASRN='7732-18-5')
@@ -143,6 +153,9 @@ def test_VaporPressure():
     with pytest.raises(ValueError):
         w.add_tabular_data(Ts=Ts_rev, properties=Ps)
 
+@pytest.mark.meta_T_dept
+def test_VaporPressure_cycloheptane():
+
     # Get a check for Antoine Extended
     cycloheptane = VaporPressure(Tb=391.95, Tc=604.2, Pc=3820000.0, omega=0.2384, CASRN='291-64-5')
     cycloheptane.method = ('ANTOINE_EXTENDED_POLING')
@@ -300,12 +313,13 @@ def test_VaporPressure_fitting7_reduced_fit_params_with_jac():
 @pytest.mark.fitting
 @pytest.mark.meta_T_dept
 def test_VaporPressure_fitting8_TRC_AntoineExtended():
+    hard_CASs = frozenset(['110-82-7'])
     for i, CAS in enumerate(chemicals.vapor_pressure.Psat_data_AntoineExtended.index):
         obj = VaporPressure(CASRN=CAS)
         Ts = linspace(obj.ANTOINE_EXTENDED_POLING_Tmin, obj.ANTOINE_EXTENDED_POLING_Tmax, 10)
         props_calc = [obj.calculate(T, ANTOINE_EXTENDED_POLING) for T in Ts]
         res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='TRC_Antoine_extended',
-                              do_statistics=True, use_numba=False, 
+                              do_statistics=True, use_numba=False, multiple_tries=CAS in hard_CASs,# multiple_tries_max_err=1e-4,
                               fit_method='lm', model_kwargs={'Tc': obj.ANTOINE_EXTENDED_POLING_coefs[0], 
                                                              'to': obj.ANTOINE_EXTENDED_POLING_coefs[1]})
         assert stats['MAE'] < 1e-4
@@ -431,7 +445,7 @@ def test_VaporPressure_extrapolation_solve_prop():
     assert_close(cycloheptane.solve_property(3e7), 979.2026813626704)
 
 def test_VaporPressure_bestfit_derivatives():
-    obj = VaporPressure(poly_fit=(175.7, 512.49, [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
+    obj = VaporPressure(exp_poly_fit=(175.7, 512.49, [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
                                                 -2.443464113936029e-07, 7.893819658700523e-05, -0.016615779444332356, 2.1842496316772264, -134.19766175812708]))
     assert_close(obj.T_dependent_property(300), 18601.061401014867, rtol=1e-11)
     assert_close(obj.T_dependent_property_derivative(300), 954.1652489206775, rtol=1e-11)
@@ -461,38 +475,95 @@ def test_VaporPressure_extrapolation_AB():
                      obj.T_dependent_property(obj.WAGNER_MCGARRY_Tmin+1e-6))
 
 
-def test_VaporPressure_fast_Psat_poly_fit():
-    corr = VaporPressure(poly_fit=(273.17, 647.086, [-2.8478502840358144e-21, 1.7295186670575222e-17, -4.034229148562168e-14, 5.0588958391215855e-11, -3.861625996277003e-08, 1.886271475957639e-05, -0.005928371869421494, 1.1494956887882308, -96.74302379151317]))
-    # Low temperature values - up to 612 Pa
-    assert_close(corr.solve_property(1e-5), corr.solve_prop_poly_fit(1e-5), rtol=1e-10)
-    assert_close(corr.solve_property(1), corr.solve_prop_poly_fit(1), rtol=1e-10)
-    assert_close(corr.solve_property(100), corr.solve_prop_poly_fit(100), rtol=1e-10)
+# @pytest.mark.meta_T_dept
+# def test_VaporPressure_fast_Psat_poly_fit():
+#     corr = VaporPressure(exp_poly_fit=(273.17, 647.086, [-2.8478502840358144e-21, 1.7295186670575222e-17, -4.034229148562168e-14, 5.0588958391215855e-11, -3.861625996277003e-08, 1.886271475957639e-05, -0.005928371869421494, 1.1494956887882308, -96.74302379151317]))
+    
+#     # Low transition
+#     P_trans = corr.exp_poly_fit_Tmin_value
+#     assert_close(corr.solve_property(P_trans), corr.solve_property_exp_poly_fit(P_trans), rtol=1e-10)
+#     assert_close(corr.solve_property(P_trans + 1e-7), corr.solve_property_exp_poly_fit(P_trans + 1e-7), rtol=1e-10)
+    
+#     # High transition
+#     P_trans = corr.exp_poly_fit_Tmax_value
+#     assert_close(corr.solve_property(P_trans), corr.solve_property_exp_poly_fit(P_trans), rtol=1e-10)
+#     assert_close(corr.solve_property(P_trans + 1e-7), corr.solve_property_exp_poly_fit(P_trans + 1e-7), rtol=1e-10)
 
-    P_trans = exp(corr.poly_fit_Tmin_value)
-    assert_close(corr.solve_property(P_trans), corr.solve_prop_poly_fit(P_trans), rtol=1e-10)
-    assert_close(corr.solve_property(P_trans + 1e-7), corr.solve_prop_poly_fit(P_trans + 1e-7), rtol=1e-10)
 
-    # Solver region
-    assert_close(corr.solve_property(1e5), corr.solve_prop_poly_fit(1e5), rtol=1e-10)
-    assert_close(corr.solve_property(1e7), corr.solve_prop_poly_fit(1e7), rtol=1e-10)
+#     # Low temperature values - up to 612 Pa
+#     assert_close(corr.solve_property(1e-5), corr.solve_property_exp_poly_fit(1e-5), rtol=1e-10)
+#     assert_close(corr.solve_property(1), corr.solve_property_exp_poly_fit(1), rtol=1e-10)
+#     assert_close(corr.solve_property(100), corr.solve_property_exp_poly_fit(100), rtol=1e-10)
 
-    P_trans = exp(corr.poly_fit_Tmax_value)
-    assert_close(corr.solve_property(P_trans), corr.solve_prop_poly_fit(P_trans), rtol=1e-10)
-    assert_close(corr.solve_property(P_trans + 1e-7), corr.solve_prop_poly_fit(P_trans + 1e-7), rtol=1e-10)
 
-    # High T
-    assert_close(corr.solve_property(1e8), corr.solve_prop_poly_fit(1e8), rtol=1e-10)
+#     # Solver region
+#     assert_close(corr.solve_property(1e5), corr.solve_property_exp_poly_fit(1e5), rtol=1e-10)
+#     assert_close(corr.solve_property(1e7), corr.solve_property_exp_poly_fit(1e7), rtol=1e-10)
 
-    # Extrapolation
-    from thermo.vapor_pressure import POLY_FIT, BEST_FIT_AB, BEST_FIT_ABC
-    obj = VaporPressure(poly_fit=(178.01, 591.74, [-8.638045111752356e-20, 2.995512203611858e-16, -4.5148088801006036e-13, 3.8761537879200513e-10, -2.0856828984716705e-07, 7.279010846673517e-05, -0.01641020023565049, 2.2758331029405516, -146.04484159879843]))
-    assert_close(obj.calculate(1000, BEST_FIT_AB), 78666155.90418352, rtol=1e-10)
-    assert_close(obj.calculate(1000, BEST_FIT_ABC), 156467764.5930495, rtol=1e-10)
+#     # High T
+#     assert_close(corr.solve_property(1e8), corr.solve_property_exp_poly_fit(1e8), rtol=1e-10)
 
-    assert_close(obj.calculate(400, POLY_FIT), 157199.6909849476, rtol=1e-10)
-    assert_close(obj.calculate(400, BEST_FIT_AB), 157199.6909849476, rtol=1e-10)
-    assert_close(obj.calculate(400, BEST_FIT_ABC), 157199.6909849476, rtol=1e-10)
+#     # Extrapolation
+#     from thermo.vapor_pressure import POLY_FIT, BEST_FIT_AB, BEST_FIT_ABC
+#     obj = VaporPressure(poly_fit=(178.01, 591.74, [-8.638045111752356e-20, 2.995512203611858e-16, -4.5148088801006036e-13, 3.8761537879200513e-10, -2.0856828984716705e-07, 7.279010846673517e-05, -0.01641020023565049, 2.2758331029405516, -146.04484159879843]))
+#     assert_close(obj.calculate(1000, BEST_FIT_AB), 78666155.90418352, rtol=1e-10)
+#     assert_close(obj.calculate(1000, BEST_FIT_ABC), 156467764.5930495, rtol=1e-10)
 
+#     assert_close(obj.calculate(400, POLY_FIT), 157199.6909849476, rtol=1e-10)
+#     assert_close(obj.calculate(400, BEST_FIT_AB), 157199.6909849476, rtol=1e-10)
+#     assert_close(obj.calculate(400, BEST_FIT_ABC), 157199.6909849476, rtol=1e-10)
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_generic_polynomial_exp_parameters():
+    coeffs = [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
+                                                -2.443464113936029e-07, 7.893819658700523e-05, -0.016615779444332356, 2.1842496316772264, -134.19766175812708]
+    
+    obj_bestfit = VaporPressure(exp_poly_fit=(175.7, 512.49, coeffs))
+    obj_polynomial = VaporPressure(exp_polynomial_parameters={'test': {'coeffs': coeffs,
+                                                        'Tmin': 175.7, 'Tmax': 512.49}})
+    assert_close(obj_bestfit.T_dependent_property(300), 18601.061401014867, rtol=1e-11)
+    
+    assert_close(obj_polynomial(300), obj_bestfit.T_dependent_property(300), rtol=1e-13)
+
+    assert VaporPressure.from_json(obj_bestfit.as_json()) == obj_bestfit
+    assert eval(str(obj_bestfit)) == obj_bestfit
+
+    assert VaporPressure.from_json(obj_polynomial.as_json()) == obj_polynomial
+    assert eval(str(obj_polynomial)) == obj_polynomial
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_generic_polynomial_exp_parameters_complicated():
+    coeffs = [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
+    -2.443464113936029e-07, 7.893819658700523e-05, -0.016615779444332356, 2.1842496316772264, -134.19766175812708]
+    T = 300.0
+    
+    obj2 = VaporPressure(exp_poly_fit=(175.7, 512.49, coeffs))
+    assert_close(obj2(T), 18601.061401014867, rtol=1e-13)
+    
+    assert_close(obj2.T_dependent_property_derivative(T), 954.1652489206775, rtol=1e-14)
+    assert_close(obj2.T_dependent_property_derivative(T, order=2), 41.8787546283273, rtol=1e-14)
+    assert_close(obj2.T_dependent_property_derivative(T, order=3), 1.496803960985584, rtol=1e-13)
+    
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_exp_stablepoly_fit():
+    obj2 = VaporPressure(Tc=591.72, exp_stablepoly_fit=((309.0, 591.72, [0.008603558174828078, 0.007358688688856427, -0.016890323025782954, -0.005289197721114957, -0.0028824712174469625, 0.05130960832946553, -0.12709896610233662, 0.37774977659528036, -0.9595325030688526, 2.7931528759840174, 13.10149649770156])))
+    assert_close(obj2(400), 157191.01706242564, rtol=1e-13)
+    assert_close(obj2.T_dependent_property_derivative(400, order=1), 4056.436943642117, rtol=1e-13)
+    
+    assert_close(obj2.T_dependent_property_derivative(400, order=2), 81.32645570045084, rtol=1e-13)
+    assert_close(obj2.T_dependent_property_derivative(400, order=3), 1.103603650822488, rtol=1e-13)
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_exp_cheb_fit():
+    obj2 = VaporPressure(Tc=591.72, exp_cheb_fit=((309.0, 591.72, [12.570668791524573, 3.1092695610681673, -0.5485217707981505, 0.11115875762247596, -0.01809803938553478, 0.003674911307077089, -0.00037626163070525465, 0.0001962813915017403, 6.120764548889213e-05, 3.602752453735203e-05])))
+    assert_close(obj2(300), 4186.189338463003, rtol=1e-13)
+    
+    assert_close(obj2.T_dependent_property_derivative(400, order=1), 4056.277312107932, rtol=1e-13)
+    
+    assert_close(obj2.T_dependent_property_derivative(400, order=2), 81.34302144188977, rtol=1e-13)
+    assert_close(obj2.T_dependent_property_derivative(400, order=3),1.105438780935656, rtol=1e-13)
+    
 @pytest.mark.meta_T_dept
 def test_VaporPressure_extrapolation_no_validation():
     N2 = VaporPressure(CASRN='7727-37-9', extrapolation='DIPPR101_ABC')
@@ -503,14 +574,13 @@ def test_VaporPressure_extrapolation_no_validation():
 
 @pytest.mark.meta_T_dept
 def test_VaporPressure_fast_Psat_poly_fit_extrapolation():
-    obj = VaporPressure(poly_fit=(175.7, 512.49, [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
+    obj = VaporPressure(exp_poly_fit=(175.7, 512.49, [-1.446088049406911e-19, 4.565038519454878e-16, -6.278051259204248e-13, 4.935674274379539e-10,
                                                 -2.443464113936029e-07, 7.893819658700523e-05, -0.016615779444332356, 2.1842496316772264, -134.19766175812708]))
     obj.extrapolation = 'AntoineAB|DIPPR101_ABC'
-    # If the extrapolation is made generic, the extrapolated results will change
-    # right now it is not going off the direct property calc
-    assert_close(obj.solve_property(.0000000000001), 3.2040851644645945)
+    assert_close(obj.solve_property(1e-13), 88.65839225764933)
     assert_close(obj.solve_property(300), 237.7793675652309)
-    assert_close(obj.solve_property(1e8), 661.6135315674736)
+    assert_close(1e8, obj.extrapolate(obj.solve_property(1e8), 'EXP_POLY_FIT'))
+    assert_close(obj.extrapolate(800, 'EXP_POLY_FIT'), 404793143.0358333)
 
 @pytest.mark.meta_T_dept
 def test_VaporPressure_Antoine_inputs():
@@ -542,6 +612,12 @@ def test_VaporPressure_Antoine_inputs():
         obj.add_correlation(name='WebBook', model='Antoine', Tmin=177.70, Tmax=264.93,  A=3.45604+5, B=1044.038, C=-53.893)
     with pytest.raises(ValueError):
         obj.add_correlation(name='WebBook4', model='NOTAMODEL', Tmin=177.70, Tmax=264.93,  A=3.45604+5, B=1044.038, C=-53.893)
+        
+    
+    # Test with the new 'coefficients' input method
+    obj = VaporPressure(Antoine_parameters={'WebBook': {'coefficients': [8.45604, 1044.038, -53.893],
+                                                    'Tmin': 177.7, 'Tmax': 264.93}})
+    assert_close(obj(220), 148.15143004993493, rtol=1e-13)
 
 @pytest.mark.meta_T_dept
 def test_VaporPressure_DIPPR101_inputs():
@@ -564,3 +640,61 @@ def test_VaporPressure_DIPPR101_inputs():
     assert obj == obj2
     assert hash(obj) == hash0
     assert hash(obj2) == hash0
+
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_extrapolate_derivatives():
+    obj = VaporPressure(extrapolation='DIPPR101_ABC|AntoineAB', exp_poly_fit=(273.17, 647.086, [-2.8478502840358144e-21, 1.7295186670575222e-17, -4.034229148562168e-14, 5.0588958391215855e-11, -3.861625996277003e-08, 1.886271475957639e-05, -0.005928371869421494, 1.1494956887882308, -96.74302379151317]))
+    assert_close(obj.T_dependent_property_derivative(230), 1.4571835115958078, rtol=1e-11)
+    assert_close(obj.T_dependent_property_derivative(230, order=2), 0.14109259717547848, rtol=1e-11)
+    assert_close(obj.T_dependent_property_derivative(230, order=3), 0.012236116569167774, rtol=1e-11)
+    
+    assert_close(obj.T_dependent_property_derivative(700, order=1), 403088.9468522063, rtol=1e-8)
+    assert_close(obj.T_dependent_property_derivative(700, order=2), 2957.4520772886904, rtol=1e-8)
+
+@pytest.mark.meta_T_dept
+def test_VaporPressure_weird_signatures():
+    from thermo.utils import PROPERTY_TRANSFORM_LN, PROPERTY_TRANSFORM_DLN, PROPERTY_TRANSFORM_D2LN, PROPERTY_TRANSFORM_D_X, PROPERTY_TRANSFORM_D2_X
+
+    obj = VaporPressure(extrapolation='DIPPR101_ABC|AntoineAB', exp_poly_fit=(273.17, 647.086, [-2.8478502840358144e-21, 1.7295186670575222e-17, -4.034229148562168e-14, 5.0588958391215855e-11, -3.861625996277003e-08, 1.886271475957639e-05, -0.005928371869421494, 1.1494956887882308, -96.74302379151317]))
+    
+    # Within range
+    assert_close(obj.T_dependent_property_transform(300, PROPERTY_TRANSFORM_LN),
+                 log(obj.T_dependent_property(300)))
+    
+    assert_close(obj.T_dependent_property_transform(300, PROPERTY_TRANSFORM_D_X),
+                 obj.T_dependent_property_derivative(300)/obj.T_dependent_property(300))
+    
+    assert_close(obj.T_dependent_property_transform(300, PROPERTY_TRANSFORM_D2_X),
+                 obj.T_dependent_property_derivative(300, 2)/obj.T_dependent_property(300))
+    
+    dln = derivative(lambda T: log(obj(T)), 300, dx=300*1e-6)
+    assert_close(dln, obj.T_dependent_property_transform(300, PROPERTY_TRANSFORM_DLN))
+    
+    dln = derivative(lambda T: log(obj(T)), 300, n=2, dx=300*1e-5)
+    assert_close(dln, obj.T_dependent_property_transform(300, PROPERTY_TRANSFORM_D2LN), rtol=1e-5)
+
+    # Extrapolations
+    for extrapolation in ('interp1d', 'DIPPR101_ABC', 'AntoineAB'):
+        obj.extrapolation = extrapolation
+        for T in (100, 1000):
+            assert_close(obj.T_dependent_property_transform(T, PROPERTY_TRANSFORM_LN),
+                         log(obj.T_dependent_property(T)))
+        
+            assert_close(obj.T_dependent_property_transform(T, PROPERTY_TRANSFORM_D_X),
+                         obj.T_dependent_property_derivative(T)/obj.T_dependent_property(T))
+        
+            assert_close(obj.T_dependent_property_transform(T, PROPERTY_TRANSFORM_D2_X),
+                         obj.T_dependent_property_derivative(T, 2)/obj.T_dependent_property(T))
+        
+            dln = derivative(lambda T: log(obj(T)), T, dx=T*1e-6)
+            assert_close(dln, obj.T_dependent_property_transform(T, PROPERTY_TRANSFORM_DLN))
+        
+            dln = derivative(lambda T: log(obj(T)), T, n=2, dx=T*1e-5)
+            assert_close(dln, obj.T_dependent_property_transform(T, PROPERTY_TRANSFORM_D2LN), rtol=4e-4)
+    
+@pytest.mark.meta_T_dept
+def test_VaporPressure_WebBook():
+    obj = VaporPressure(CASRN='7440-57-5')
+    obj.method = 'ANTOINE_WEBBOOK'
+    assert_close(obj(3000), 36784.98996094166, rtol=1e-13)
\ No newline at end of file
