@@ -69,10 +69,11 @@ from __future__ import division
 
 __all__ = ['GibbsExcess', 'IdealSolution']
 from fluids.constants import R, R_inv
-from fluids.numerics import numpy as np
+from fluids.numerics import numpy as np, trunc_exp
 from chemicals.utils import exp, log
 from chemicals.utils import normalize, dxs_to_dns, dxs_to_dn_partials, dns_to_dn_partials, d2xs_to_dxdn_partials, hash_any_primitive
 from thermo import serialize
+from thermo.fitting import fit_customized
 
 try:
     npexp, ones, zeros, array, ndarray = np.exp, np.ones, np.zeros, np.array, np.ndarray
@@ -281,11 +282,19 @@ class GibbsExcess(object):
     immutable.
 
     '''
-    x_infinite_dilution = 0.0
+    _x_infinite_dilution = 0.0
     '''When set, this will be the limiting mole fraction used to approximate
     the :obj:`gammas_infinite_dilution` calculation. This is important
     as not all models can mathematically be evaluated at zero mole-fraction.'''
     
+    
+    _point_properties = ('CpE', 'GE', 'HE', 'SE', 'd2GE_dT2', 'd2GE_dTdns',
+                         'd2GE_dTdxs', 'd2GE_dxixjs', 'd2nGE_dTdns', 'd2nGE_dninjs',
+                         'dGE_dT', 'dGE_dns', 'dGE_dxs', 'dHE_dT', 'dHE_dns', 'dHE_dxs',
+                         'dSE_dT', 'dSE_dns', 'dSE_dxs', 'dgammas_dT', 'dgammas_dns',
+                         'dnGE_dns', 'dnHE_dns', 'dnSE_dns', 'gammas')
+    '''These are all methods which take no arguments. For use in testing.'''
+    
     def __init_subclass__(cls):
         cls.__full_path__ = "%s.%s" %(cls.__module__, cls.__qualname__)
 
@@ -345,7 +354,7 @@ class GibbsExcess(object):
         except AttributeError:
             pass
         to_hash = [self.__class__.__name__, self.N]
-        for k in self.model_attriubtes:
+        for k in self._model_attributes:
             v = getattr(self, k)
             if type(v) is ndarray:
                 v = v.tolist()
@@ -839,7 +848,7 @@ class GibbsExcess(object):
         '''
         T, N = self.T, self.N
         xs_base = self.xs
-        x_infinite_dilution = self.x_infinite_dilution
+        x_infinite_dilution = self._x_infinite_dilution
         if self.scalar:
             gammas_inf = [0.0]*N
             copy_fun = list
@@ -878,7 +887,7 @@ class GibbsExcess(object):
         if self.scalar:
             dG_dns = dxs_to_dn_partials(dG_dxs, self.xs, GE)
             RT_inv = 1.0/(R*self.T)
-            gammas = [exp(i*RT_inv) for i in dG_dns]
+            gammas = [trunc_exp(i*RT_inv) for i in dG_dns]
         else:
             gammas = gibbs_excess_gammas(self.xs, dG_dxs, GE, self.T)
             if type(gammas) is list:
@@ -904,7 +913,7 @@ class GibbsExcess(object):
         Returns
         -------
         dgammas_dns : list[list[float]]
-            Mole number derivatives of activity coefficients, [-]
+            Mole number derivatives of activity coefficients, [1/mol]
 
         Notes
         -----
@@ -1012,6 +1021,24 @@ class GibbsExcess(object):
             dgammas_dT = array(dgammas_dT)
         self._dgammas_dT = dgammas_dT
         return dgammas_dT
+    
+    @classmethod
+    def _regress_binary_parameters(cls, gammas, xs, fitting_func, fit_parameters,
+                                   use_fit_parameters, initial_guesses=None, analytical_jac=None,
+                                   **kwargs):
+
+        fit_kwargs = dict(fit_method='lm', 
+                    # fit_method='differential_evolution', 
+                   objective='MeanSquareErr', multiple_tries_max_objective='MeanRelErr', 
+                   initial_guesses=initial_guesses, analytical_jac=analytical_jac,
+                   solver_kwargs=None, use_numba=False, multiple_tries=False,
+                   do_statistics=True, multiple_tries_max_err=1e-5)
+        fit_kwargs.update(kwargs)
+         
+             
+        res = fit_customized(xs, data=gammas, fitting_func=fitting_func, fit_parameters=fit_parameters, use_fit_parameters=use_fit_parameters,
+                    **fit_kwargs)
+        return res
 
 
 class IdealSolution(GibbsExcess):
@@ -1042,7 +1069,7 @@ class IdealSolution(GibbsExcess):
     >>> model.dgammas_dT()
     [0.0, 0.0, 0.0, 0.0]
     '''
-    model_attriubtes = ()
+    _model_attributes = ()
     
     model_id = 0
 
