@@ -34,7 +34,8 @@ UNIQUAC Class
 
 .. autoclass:: UNIQUAC
     :members: to_T_xs, GE, dGE_dT, d2GE_dT2, d3GE_dT3, d2GE_dTdxs, dGE_dxs,
-              d2GE_dxixjs, taus, dtaus_dT, d2taus_dT2, d3taus_dT3, phis, thetas
+              d2GE_dxixjs, taus, dtaus_dT, d2taus_dT2, d3taus_dT3, phis, 
+              thetas, regress_binary_parameters
     :undoc-members:
     :show-inheritance:
     :exclude-members:
@@ -46,11 +47,11 @@ UNIQUAC Functional Calculations
 
 from __future__ import division
 from math import log, exp
-from fluids.numerics import numpy as np
+from fluids.numerics import numpy as np, trunc_exp
 from fluids.constants import R
 from thermo.activity import GibbsExcess, interaction_exp, dinteraction_exp_dT, d2interaction_exp_dT2, d3interaction_exp_dT3
 
-__all__ = ['UNIQUAC', 'UNIQUAC_gammas']
+__all__ = ['UNIQUAC', 'UNIQUAC_gammas', 'UNIQUAC_gammas_binary', 'UNIQUAC_gammas_binaries']
 
 try:
     array, zeros, npsum, nplog = np.array, np.zeros, np.sum, np.log
@@ -309,6 +310,21 @@ class UNIQUAC(GibbsExcess):
     by the UNIQUAC equation. This model is capable of representing VL and LL
     behavior.
 
+    .. math::
+        \frac{G^E}{RT} = \sum_i x_i \ln\frac{\phi_i}{x_i}
+        + \frac{z}{2}\sum_i q_i x_i \ln\frac{\theta_i}{\phi_i}
+        - \sum_i q_i x_i \ln\left(\sum_j \theta_j \tau_{ji}   \right)
+
+    .. math::
+        \phi_i = \frac{r_i x_i}{\sum_j r_j x_j}
+
+    .. math::
+        \theta_i = \frac{q_i x_i}{\sum_j q_j x_j}
+
+    .. math::
+        \tau_{ij} = \exp\left[a_{ij}+\frac{b_{ij}}{T}+c_{ij}\ln T
+                + d_{ij}T + \frac{e_{ij}}{T^2} + f_{ij}{T^2}\right]
+
     Parameters
     ----------
     T : float
@@ -326,21 +342,20 @@ class UNIQUAC(GibbsExcess):
         element list with parameters [`a`, `b`, `c`, `d`, `e`, `f`];
         either `tau_coeffs` or `ABCDEF` are required, [-]
     ABCDEF : tuple[list[list[float]], 6], optional
-        Contains the following. One of `tau_coeffs` or `ABCDEF` are
-        required, [-]
-
-        a : list[list[float]] or None
-            `a` parameters used in calculating :obj:`UNIQUAC.taus`, [-]
-        b : list[list[float]] or None
-            `b` parameters used in calculating :obj:`UNIQUAC.taus`, [K]
-        c : list[list[float]] or None
-            `c` parameters used in calculating :obj:`UNIQUAC.taus`, [-]
-        d : list[list[float]] or None
-            `d` paraemeters used in calculating :obj:`UNIQUAC.taus`, [1/K]
-        e : list[list[float]] or None
-            `e` parameters used in calculating :obj:`UNIQUAC.taus`, [K^2]
-        f : list[list[float]] or None
-            `f` parameters used in calculating :obj:`UNIQUAC.taus`, [1/K^2]
+        Contains the following. One of `tau_coeffs` or `ABCDEF` or some of the
+        `tau_as`, etc parameters are required, [-]
+    tau_as : list[list[float]] or None, optional
+        `a` parameters used in calculating :obj:`UNIQUAC.taus`, [-]
+    tau_bs : list[list[float]] or None, optional
+        `b` parameters used in calculating :obj:`UNIQUAC.taus`, [K]
+    tau_cs : list[list[float]] or None, optional
+        `c` parameters used in calculating :obj:`UNIQUAC.taus`, [-]
+    tau_ds : list[list[float]] or None, optional
+        `d` paraemeters used in calculating :obj:`UNIQUAC.taus`, [1/K]
+    tau_es : list[list[float]] or None, optional
+        `e` parameters used in calculating :obj:`UNIQUAC.taus`, [K^2]
+    tau_fs : list[list[float]] or None, optional
+        `f` parameters used in calculating :obj:`UNIQUAC.taus`, [1/K^2]
 
     Attributes
     ----------
@@ -366,7 +381,9 @@ class UNIQUAC(GibbsExcess):
 
     Examples
     --------
-
+    
+    **Example 1**
+    
     Example 5.19 in [2]_ includes the calculation of liquid-liquid activity
     coefficients for the water-ethanol-benzene system. Two calculations are
     reproduced accurately here. Note that the DDBST-style coefficients assume
@@ -407,6 +424,8 @@ class UNIQUAC(GibbsExcess):
     >>> GE.HE(), GE.SE(), GE.dHE_dT(), GE.dSE_dT()
     (-153.19624152, -6.69851118521, 4.7394001431, 0.0158960259705)
 
+    **Example 2**
+    
     Another problem is 8.32 in [1]_ - acetonitrile, benzene, n-heptane at
     45 °C. The sign flip is needed here as well to convert their single
     temperature-dependent values into the correct form, but it has already been
@@ -426,6 +445,45 @@ class UNIQUAC(GibbsExcess):
 
     The given values in [1]_ are [7.15, 1.25, 1.06].
 
+    **Example 3**
+    
+    ChemSep is a program for modeling distillation. Chemsep ships with a 
+    permissive license several
+    sets of binary interaction parameters. The UNIQUAC parameters in it can
+    be accessed from Thermo as follows. In the following case, we compute
+    activity coefficients of the ethanol-water system at mole fractions of
+    [.252, 0.748].
+    
+    >>> from thermo.interaction_parameters import IPDB
+    >>> CAS1, CAS2 = '64-17-5', '7732-18-5'
+    >>> xs = [0.252, 0.748]
+    >>> rs = [2.11, 0.92]
+    >>> qs = [1.97, 1.400]
+    >>> N = 2
+    >>> T = 343.15
+    >>> tau_bs = IPDB.get_ip_asymmetric_matrix(name='ChemSep UNIQUAC', CASs=['64-17-5', '7732-18-5'], ip='bij')
+    >>> GE = UNIQUAC(T=T, xs=xs, rs=rs, qs=qs, tau_bs=tau_bs)
+    >>> GE.gammas()
+    [1.977454, 1.1397696]
+
+    In ChemSep, the form of the UNIQUAC `tau` equation is
+    
+    .. math::
+        \tau_{ij} = \exp\left( \frac{-A_{ij}}{RT}\right)
+    
+    The parameters were converted to the form used by Thermo as follows:
+        
+    .. math::
+        b_{ij} = \frac{-A_{ij}}{R}= \frac{-A_{ij}}{1.9872042586408316}
+        
+    
+    This system was chosen because there is also a sample problem for the same
+    components from the DDBST which can be found here:
+    http://chemthermo.ddbst.com/Problems_Solutions/Mathcad_Files/P05.01c%20VLE%20Behavior%20of%20Ethanol%20-%20Water%20Using%20UNIQUAC.xps
+    
+    In that example, with different data sets and parameters, they obtain at
+    the same conditions activity coefficients of [2.359, 1.244].
+    
     References
     ----------
     .. [1] Poling, Bruce E., John M. Prausnitz, and John P. O’Connell. The
@@ -435,10 +493,10 @@ class UNIQUAC(GibbsExcess):
        Chemical Thermodynamics for Process Simulation. John Wiley & Sons, 2019.
     '''
     z = 10.0
-    x_infinite_dilution = 1e-12
+    _x_infinite_dilution = 1e-12
     model_id = 300
 
-    model_attriubtes = ('tau_coeffs_A', 'tau_coeffs_B', 'tau_coeffs_C',
+    _model_attributes = ('tau_coeffs_A', 'tau_coeffs_B', 'tau_coeffs_C',
                         'tau_coeffs_D', 'tau_coeffs_E', 'tau_coeffs_F',
                         'rs', 'qs')
 
@@ -448,8 +506,9 @@ class UNIQUAC(GibbsExcess):
                  self.tau_coeffs_D, self.tau_coeffs_E, self.tau_coeffs_F))
         return s
 
-    def __init__(self, T, xs, rs, qs, tau_coeffs=None,
-                 ABCDEF=None):
+    def __init__(self, T, xs, rs, qs, tau_coeffs=None, ABCDEF=None, 
+                 tau_as=None, tau_bs=None, tau_cs=None, tau_ds=None, 
+                 tau_es=None, tau_fs=None):
         self.T = T
         self.xs = xs
         self.scalar = scalar = type(rs) is list
@@ -458,15 +517,29 @@ class UNIQUAC(GibbsExcess):
 
         self.N = N = len(rs)
 
-        if ABCDEF is not None:
-            all_lengths = tuple(len(coeffs) for coeffs in ABCDEF if coeffs is not None)
-            if len(set(all_lengths)) > 1:
-                raise ValueError("Coefficient arrays of different size found: %s" %(all_lengths,))
-            all_lengths_inner = tuple(len(coeffs[0]) for coeffs in ABCDEF if coeffs is not None)
-            if len(set(all_lengths_inner)) > 1:
-                raise ValueError("Coefficient arrays of different size found: %s" %(all_lengths_inner,))
-        elif tau_coeffs is not None:
+        multiple_inputs = (tau_as, tau_bs, tau_cs, tau_ds, tau_es, tau_fs)
+        
+        input_count = ((tau_coeffs is not None) + (ABCDEF is not None) 
+                       + (any(i is not None for i in multiple_inputs)))
+        if input_count > 1:
+            raise ValueError("Input only one of tau_coeffs, ABCDEF, or (tau_as..)")
+
+        if ABCDEF is None:
+            ABCDEF = multiple_inputs
+
+
+        if tau_coeffs is not None:
             pass
+        elif ABCDEF is not None:
+            try:
+                all_lengths = tuple(len(coeffs) for coeffs in ABCDEF if coeffs is not None)
+                if len(set(all_lengths)) > 1:
+                    raise ValueError("Coefficient arrays of different size found: %s" %(all_lengths,))
+                all_lengths_inner = tuple(len(coeffs[0]) for coeffs in ABCDEF if coeffs is not None)
+                if len(set(all_lengths_inner)) > 1:
+                    raise ValueError("Coefficient arrays of different size found: %s" %(all_lengths_inner,))
+            except:
+                raise ValueError("Coefficients not input correctly")
         else:
             raise ValueError("`tau_coeffs` or `ABCDEF` is required")
         
@@ -475,7 +548,22 @@ class UNIQUAC(GibbsExcess):
         else:
             self.zero_coeffs = zero_coeffs = zeros((N, N))
 
-        if ABCDEF is not None:
+        if tau_coeffs is not None:
+            if scalar:
+                self.tau_coeffs_A = [[i[0] for i in l] for l in tau_coeffs]
+                self.tau_coeffs_B = [[i[1] for i in l] for l in tau_coeffs]
+                self.tau_coeffs_C = [[i[2] for i in l] for l in tau_coeffs]
+                self.tau_coeffs_D = [[i[3] for i in l] for l in tau_coeffs]
+                self.tau_coeffs_E = [[i[4] for i in l] for l in tau_coeffs]
+                self.tau_coeffs_F = [[i[5] for i in l] for l in tau_coeffs]
+            else:
+                self.tau_coeffs_A = array(tau_coeffs[:,:,0], order='C', copy=True)
+                self.tau_coeffs_B = array(tau_coeffs[:,:,1], order='C', copy=True)
+                self.tau_coeffs_C = array(tau_coeffs[:,:,2], order='C', copy=True)
+                self.tau_coeffs_D = array(tau_coeffs[:,:,3], order='C', copy=True)
+                self.tau_coeffs_E = array(tau_coeffs[:,:,4], order='C', copy=True)
+                self.tau_coeffs_F = array(tau_coeffs[:,:,5], order='C', copy=True)
+        else:
             len_ABCDEF = len(ABCDEF)
             if len_ABCDEF == 0 or ABCDEF[0] is None:
                 self.tau_coeffs_A = zero_coeffs
@@ -501,22 +589,6 @@ class UNIQUAC(GibbsExcess):
                 self.tau_coeffs_F = zero_coeffs
             else:
                 self.tau_coeffs_F = ABCDEF[5]
-        else:
-            if tau_coeffs is not None:
-                if scalar:
-                    self.tau_coeffs_A = [[i[0] for i in l] for l in tau_coeffs]
-                    self.tau_coeffs_B = [[i[1] for i in l] for l in tau_coeffs]
-                    self.tau_coeffs_C = [[i[2] for i in l] for l in tau_coeffs]
-                    self.tau_coeffs_D = [[i[3] for i in l] for l in tau_coeffs]
-                    self.tau_coeffs_E = [[i[4] for i in l] for l in tau_coeffs]
-                    self.tau_coeffs_F = [[i[5] for i in l] for l in tau_coeffs]
-                else:
-                    self.tau_coeffs_A = array(tau_coeffs[:,:,0], order='C', copy=True)
-                    self.tau_coeffs_B = array(tau_coeffs[:,:,1], order='C', copy=True)
-                    self.tau_coeffs_C = array(tau_coeffs[:,:,2], order='C', copy=True)
-                    self.tau_coeffs_D = array(tau_coeffs[:,:,3], order='C', copy=True)
-                    self.tau_coeffs_E = array(tau_coeffs[:,:,4], order='C', copy=True)
-                    self.tau_coeffs_F = array(tau_coeffs[:,:,5], order='C', copy=True)
 
     def to_T_xs(self, T, xs):
         r'''Method to construct a new :obj:`UNIQUAC` instance at
@@ -572,6 +644,7 @@ class UNIQUAC(GibbsExcess):
             except AttributeError:
                 pass
         return new
+    
 
     def taus(self):
         r'''Calculate and return the `tau` terms for the UNIQUAC model for the
@@ -1510,7 +1583,225 @@ class UNIQUAC(GibbsExcess):
         self._d2GE_dxixjs = d2GE_dxixjs
         return d2GE_dxixjs
 
+    @classmethod
+    def regress_binary_parameters(cls, gammas, xs, rs, qs, use_numba=False,
+                                  do_statistics=True, **kwargs):
+        r'''Perform a basic regression to determine the values of the `tau`
+        terms in the UNIQUAC model, given a series of known or predicted
+        activity coefficients and mole fractions. 
 
+        Parameters
+        ----------
+        gammas : list[list[float, 2]]
+            List of activity coefficient pairs, [-]
+        xs : list[list[float, 2]]
+            List of binary mole fraction pairs, [-]
+        rs : list[float]
+            Van der Waals volume parameters for each species, [-]
+        qs : list[float]
+            Surface area parameters for each species, [-]
+        use_numba : bool, optional
+            Whether or not to try to use numba to speed up the computation, [-]
+        do_statistics : bool, optional
+            Whether or not to compute statistical measures on the outputs, [-]
+        kwargs : dict
+            Extra parameters to be passed to the fitting function (not yet
+            documented), [-]
+
+        Returns
+        -------
+        parameters : dict[str, float]
+            Dimentionless interaction parameters of each compound with each 
+            other; these are the actual `tau` values. [-]
+        statistics : dict[str: float]
+            Statistics, calculated and returned only if `do_statistics` is True, [-]
+            
+        Notes
+        -----
+        Notes on getting fitting coefficients that yield gammas of 1:
+        
+            * This is possible some of the time to a pretty high accuracy
+            * This is not possible whatsoever in some cases
+            * The values of `rs`, and `qs` determine how close the fitting can be
+            * If `rs` and `qs` are close to each other, it may well fit nicely
+            * If they are distant (1.2-1.5x) they usually will not fit
+        
+        Examples
+        --------
+        
+        In the following example, the `tau` values required to zero-out the
+        coefficients for the n-pentane and n-hexane system are calculated. The
+        parameters are converted back into `aij` parameters as used by this
+        activity coefficient object, and then the calculated values are
+        verified to be fairly nearly one.
+        
+        >>> from thermo import UNIQUAC
+        >>> import numpy as np
+        >>> pts = 30
+        >>> rs = [3.8254, 4.4998]
+        >>> qs = [3.316, 3.856]
+        >>> xs = [[xi, 1.0 - xi] for xi in np.linspace(1e-7, 1-1e-7, pts)]
+        >>> gammas = [[1, 1] for i in range(pts)]
+        >>> coeffs, stats = UNIQUAC.regress_binary_parameters(gammas, xs, rs, qs)
+        >>> coeffs
+        {'tau12': 1.04220685, 'tau21': 0.95538082}
+        >>> assert stats['MAE'] < 1e-6
+        >>> tausB = tausC = tausD = tausE = tausF = [[0.0]*2 for i in range(2)]
+        >>> tausA = [[0, np.log(coeffs['tau12'])], [np.log(coeffs['tau21']), 0]]
+        >>> ABCDEF = (tausA, tausB, tausC, tausD, tausE, tausF)
+        >>> GE = UNIQUAC(T=300, xs=[.5, .5], rs=rs, qs=qs, ABCDEF=ABCDEF)
+        >>> GE.gammas()
+        [1.000000466, 1.000000180]
+        
+        Note how the `tau` coefficients need to be converted into the `a`
+        parameters of the `tau` equation. They could also have been converted
+        into any of the other parameters, but then the activity coefficients
+        predicted would no longer be close to 1 at other temperatures.
+
+        .. math::
+            \tau_{ij} = \exp\left[a_{ij}+\frac{b_{ij}}{T}+c_{ij}\ln T
+                    + d_{ij}T + \frac{e_{ij}}{T^2} + f_{ij}{T^2}\right]
+            
+            
+        The UNIQUAC model's `r` and `q` parameters create their own biases in
+        the model, based on the structure of each of the pure species. Water
+        and n-pentane are not miscible liquids; they will form two liquid
+        phases except when one component is present in trace amounts. No
+        matter the values of `tau`, it is not possible to make the UNIQUAC
+        equation predict activity coefficients very close to one for this
+        system, as shown in the following sample.
+        
+        >>> rs = [3.8254, 0.92]
+        >>> qs = [3.316, 1.4]
+        >>> pts = 6
+        >>> xs = [[xi, 1.0 - xi] for xi in np.linspace(1e-7, 1-1e-7, pts)]
+        >>> gammas = [[1, 1] for i in range(pts)]
+        >>> coeffs, stats = UNIQUAC.regress_binary_parameters(gammas, xs, rs, qs)
+        >>> stats['MAE']
+        0.0254
+        
+        '''
+        if use_numba:
+            from thermo.numba import UNIQUAC_gammas_binaries as work_func
+            rs = array(rs)
+            qs = array(qs)
+        else:
+            work_func = UNIQUAC_gammas_binaries
+        
+        def fitting_func(xs, tau12, tau21):
+            # Capture rs, qs unfortunately is necessary. Works nicely with numba though.
+            # try:
+            return work_func(xs, rs, qs, tau12, tau21)
+            # except:
+            #     print(xs.tolist(), tau12, tau21)
+        
+        
+        pts = len(xs)
+        xs_working = []
+        for i in range(pts):
+            xs_working.append(xs[i][0])
+            xs_working.append(xs[i][1])
+        gammas_working = []
+        for i in range(pts):
+            gammas_working.append(gammas[i][0])
+            gammas_working.append(gammas[i][1])
+            
+        xs_working = np.array(xs_working)
+        gammas_working = np.array(gammas_working)
+
+        return GibbsExcess._regress_binary_parameters(gammas_working, xs_working, fitting_func=fitting_func,
+                                                      fit_parameters=['tau12', 'tau21'],
+                                                      use_fit_parameters=['tau12', 'tau21'],
+                                                      initial_guesses=cls._gamma_parameter_guesses,
+                                                      analytical_jac=None,
+                                                      use_numba=use_numba,
+                                                      do_statistics=do_statistics,
+                                                      **kwargs)
+         
+    
+    _gamma_parameter_guesses = [#{'tau12': 1, 'tau21': 1}, # 1 is always tried
+                            {'tau12': 1.0529981904211922, 'tau21': 1.1976772649513237},
+                            {'tau12': 1.8748910210873349, 'tau21': 998.612171671497}, # Found seeking gamma = 1 for rs, qs = [[1.4, 7.219], [39.95, 47.2727]]
+                            {'tau12': 0.6080855151163854, 'tau21': 1.5266917396579502},  # Found seeking gamma = 1 for rs, qs = [[30.49447368421054, 38.253], [30.195389473684212, 42.39346842105263]]
+                            {'tau12': 0.75, 'tau21': 0.053}, # triethylamine and water from ChemSep main
+                            {'tau12': 0.51, 'tau21': 0.00115}, # triethylamine and water from ChemSep main low T
+                            {'tau12': 0.0003578, 'tau21': 32.6}, # acetic acid and 1-propanol from ChemSep main
+                            {'tau12': 0.00056, 'tau21': 41.9}, # acetone and chloroform from ChemSep main
+                            {'tau12': 1.45, 'tau21': 2.2e-7}, # methanol and ethene, chloro- from ChemSep main
+                            ]
+    
+    for i in range(len(_gamma_parameter_guesses)):
+        r = _gamma_parameter_guesses[i]
+        _gamma_parameter_guesses.append({'tau12': r['tau21'], 'tau21': r['tau12']})
+        
+         
+
+MIN_TAU_UNIQUAC = 1e-20
+
+def UNIQUAC_gammas_binaries(xs, rs, qs, tau12, tau21, calc=None):
+    # xs: array [x0_0, x1_0, x0_1, x1_1]
+    if tau12 < MIN_TAU_UNIQUAC:
+        tau12 = MIN_TAU_UNIQUAC
+    if tau21 < MIN_TAU_UNIQUAC:
+        tau21 = MIN_TAU_UNIQUAC
+    pts = len(xs)//2 # Always even
+    r1, r2 = rs
+    q1, q2 = qs
+    allocate_size = (pts*2)
+    if calc is None:
+        calc = [0.0]*allocate_size
+    for i in range(pts):
+        g0, g1 = UNIQUAC_gammas_binary(xs[i*2], r1, r2, q1, q2, tau12, tau21)
+        calc[i*2] = g0
+        calc[i*2+1] = g1
+    return calc
+
+def UNIQUAC_gammas_binary(x1, r1, r2, q1, q2, tau12, tau21):
+    x0 = q1*x1
+    x2 = x1 - 1
+    x3 = q2*x2
+    x4 = -tau21*x3 + x0
+    x5 = -x3
+    x6 = x0 + x5
+    x7 = 1.0/x6
+    x8 = log(x4*x7)
+    x9 = r1*x1
+    x10 = r2*x2
+    x11 = -x10 + x9
+    x12 = x11*x7
+    x13 = 5.0*log(q1*x12/r1)
+    x14 = 1/x11
+    x15 = r1*x14
+    x16 = 1 - x1
+    x17 = r2*x16
+    x18 = x17 + x9
+    x19 = x11/x18**2
+    x20 = 1/x4
+    x21 = q2*x16
+    x22 = 1/(x0 + x21)
+    x23 = x0*x22
+    x24 = x21*x22
+    x25 = x22*x6
+    x26 = 1/x18
+    x27 = x18*x22
+    x28 = q1*x27
+    x29 = 5*x14
+    x30 = x29*x6
+    x31 = tau12*x0
+    x32 = x31 + x5
+    x33 = x25/x32
+    x34 = q1**2*x1*x20*x25*(tau21*x24 + x23 - 1) + q1*x13 - q1*x3*x33*(-tau12*(1 - x23) + x24) - q1*x8 + x15*x2 - x19*x9 + x25*x29*x3*(-r1 + x28) - x28*x30*(x23 - x26*x9)
+    x35 = log(x15)
+    x36 = r2*x14
+    x37 = log(x36)
+    x38 = log(x32*x7)
+    x39 = 5*log(q2*x12/r2)
+    x40 = x23*x6
+    x41 = -q2**2*x2*x33*(x22*x31 + x24 - 1) + q2*x20*x40*(-tau21*(1 - x24) + x23) - q2*x38 + q2*x39 - x1*x36 + x10*x19 - x29*x40*(q2*x27 - r2) + x27*x3*x30*(-x17*x26 + x24)/x16
+    x42 = x0*x13 - x0*x8 + x1*x35 - x1*(x34 + x35) - x2*x37 + x2*(x37 + x41) + x3*x38 - x3*x39    
+    return (x15*trunc_exp(x34 + x42), x36*trunc_exp(x41 + x42))
+    
+    
 def UNIQUAC_gammas(xs, rs, qs, taus):
     r'''Calculates the activity coefficients of each species in a mixture
     using the Universal quasi-chemical (UNIQUAC) equation, given their mole
