@@ -90,6 +90,7 @@ EXP_CHEB_FIT = 'EXP_CHEB_FIT'
 CHEB_FIT_LN_TAU = 'CHEB_FIT_LN_TAU'
 EXP_CHEB_FIT_LN_TAU = 'EXP_CHEB_FIT_LN_TAU'
 
+IAPWS = 'IAPWS'
 DIPPR_PERRY_8E = 'DIPPR_PERRY_8E'
 VDI_TABULAR = 'VDI_TABULAR'
 VDI_PPDS = 'VDI_PPDS'
@@ -117,5 +118,5 @@ __all__ = (
     NEGLIGIBLE, LINEAR, POLY_FIT, EXP_POLY_FIT, POLY_FIT_LN_TAU, EXP_POLY_FIT_LN_TAU, 
     STABLEPOLY_FIT, EXP_STABLEPOLY_FIT, STABLEPOLY_FIT_LN_TAU, EXP_STABLEPOLY_FIT_LN_TAU,
     CHEB_FIT, EXP_CHEB_FIT, CHEB_FIT_LN_TAU, EXP_CHEB_FIT_LN_TAU,
-    DIPPR_PERRY_8E, VDI_TABULAR, VDI_PPDS, COOLPROP, 
+    DIPPR_PERRY_8E, VDI_TABULAR, VDI_PPDS, COOLPROP, IAPWS,
 )
\ No newline at end of file
